=== modified file 'bzrlib/tests/tree_implementations/__init__.py'
--- bzrlib/tests/tree_implementations/__init__.py	2007-03-12 02:35:23 +0000
+++ bzrlib/tests/tree_implementations/__init__.py	2007-04-14 11:55:51 +0000
@@ -180,16 +180,31 @@
 
     def get_tree_with_subdirs_and_all_content_types(self):
         """Return a test tree with subdirs and all content types.
+        See get_tree_with_subdirs_and_all_supported_content_types for details.
+        """
+        self.get_tree_with_subdirs_and_all_supported_content_types(True)
+
+    def get_tree_with_subdirs_and_all_supported_content_types(self, symlinks):
+        """Return a test tree with subdirs and all supported content types.
+        Some content types may not be created on some platforms
+        (like symlinks on native win32)
+
+        :param  symlinks:   control is symlink should be created in the tree.
+                            Note: if you wish to automatically set this
+                            parameters depending on underlying system,
+                            please use value returned
+                            by bzrlib.osutils.has_symlinks() function.
 
         The returned tree has the following inventory:
             [('', inventory.ROOT_ID),
              ('0file', '2file'),
              ('1top-dir', '1top-dir'),
              (u'2utf\u1234file', u'0utf\u1234file'),
-             ('symlink', 'symlink'),
+             ('symlink', 'symlink'),            # only if symlinks arg is True
              ('1top-dir/0file-in-1topdir', '1file-in-1topdir'),
              ('1top-dir/1dir-in-1topdir', '0dir-in-1topdir')]
-        where each component has the type of its name - i.e. '1file..' is afile.
+        where each component has the type of its name -
+        i.e. '1file..' is afile.
 
         note that the order of the paths and fileids is deliberately 
         mismatched to ensure that the result order is path based.
@@ -215,9 +230,10 @@
                 'This platform does not support unicode file paths.')
         tree.add(paths, ids)
         tt = transform.TreeTransform(tree)
-        root_transaction_id = tt.trans_id_tree_path('')
-        tt.new_symlink('symlink',
-            root_transaction_id, 'link-target', 'symlink')
+        if symlinks:
+            root_transaction_id = tt.trans_id_tree_path('')
+            tt.new_symlink('symlink',
+                root_transaction_id, 'link-target', 'symlink')
         tt.apply()
         return self.workingtree_to_test_tree(tree)
 

=== modified file 'bzrlib/tests/tree_implementations/test_inv.py'
--- bzrlib/tests/tree_implementations/test_inv.py	2007-03-12 03:31:12 +0000
+++ bzrlib/tests/tree_implementations/test_inv.py	2007-04-14 11:55:51 +0000
@@ -212,8 +212,7 @@
 
 class TestInventory(TestCaseWithTree):
 
-    def setUp(self):
-        super(TestInventory, self).setUp()
+    def _set_up(self):
         self.tree = self.get_tree_with_subdirs_and_all_content_types()
         self.tree.lock_read()
         self.addCleanup(self.tree.unlock)
@@ -221,6 +220,9 @@
         self.inv = self.tree.inventory
 
     def test_symlink_target(self):
+        if not has_symlinks():
+            raise TestSkipped('No symlink support')
+        self._set_up()
         if isinstance(self.tree, MutableTree):
             raise TestSkipped(
                 'symlinks not accurately represented in working trees')
@@ -228,6 +230,9 @@
         self.assertEqual(entry.symlink_target, 'link-target')
 
     def test_symlink(self):
+        if not has_symlinks():
+            raise TestSkipped('No symlink support')
+        self._set_up()
         entry = self.inv[self.inv.path2id('symlink')]
         self.assertEqual(entry.kind, 'symlink')
         self.assertEqual(None, entry.text_size)

=== modified file 'bzrlib/tests/tree_implementations/test_test_trees.py'
--- bzrlib/tests/tree_implementations/test_test_trees.py	2007-03-01 16:48:50 +0000
+++ bzrlib/tests/tree_implementations/test_test_trees.py	2007-04-14 11:55:51 +0000
@@ -16,6 +16,8 @@
 
 """Tests for the test trees used by the tree_implementations tests."""
 
+from bzrlib.osutils import has_symlinks
+from bzrlib.tests import TestSkipped
 from bzrlib.tests.tree_implementations import TestCaseWithTree
 
 
@@ -146,6 +148,8 @@
         # currently this test tree requires unicode. It might be good
         # to have it simply stop having the single unicode file in it
         # when dealing with a non-unicode filesystem.
+        if not has_symlinks():
+            raise TestSkipped('No symlink support')
         tree = self.get_tree_with_subdirs_and_all_content_types()
         tree.lock_read()
         self.addCleanup(tree.unlock)
@@ -176,6 +180,38 @@
              ('1top-dir/1dir-in-1topdir', '0dir-in-1topdir', 'directory')],
             [(path, node.file_id, node.kind) for path, node in tree.iter_entries_by_dir()])
 
+    def test_tree_with_subdirs_and_all_content_types_wo_symlinks(self):
+        # currently this test tree requires unicode. It might be good
+        # to have it simply stop having the single unicode file in it
+        # when dealing with a non-unicode filesystem.
+        tree = self.get_tree_with_subdirs_and_all_supported_content_types(False)
+        tree.lock_read()
+        self.addCleanup(tree.unlock)
+        self.assertEqual([], tree.get_parent_ids())
+        self.assertEqual([], tree.conflicts())
+        self.assertEqual([], list(tree.unknowns()))
+        # __iter__ has no strongly defined order
+        tree_root = tree.path2id('')
+        self.assertEqual(
+            set([tree_root,
+                '2file',
+                '1top-dir',
+                '1file-in-1topdir',
+                '0dir-in-1topdir',
+                 u'0utf\u1234file'.encode('utf8'),
+                 ]),
+            set(iter(tree)))
+        # note that the order of the paths and fileids is deliberately 
+        # mismatched to ensure that the result order is path based.
+        self.assertEqual(
+            [('', tree_root, 'directory'),
+             ('0file', '2file', 'file'),
+             ('1top-dir', '1top-dir', 'directory'),
+             (u'2utf\u1234file', u'0utf\u1234file'.encode('utf8'), 'file'),
+             ('1top-dir/0file-in-1topdir', '1file-in-1topdir', 'file'),
+             ('1top-dir/1dir-in-1topdir', '0dir-in-1topdir', 'directory')],
+            [(path, node.file_id, node.kind) for path, node in tree.iter_entries_by_dir()])
+
     def test_tree_with_utf8(self):
         tree = self.make_branch_and_tree('.')
         tree = self.get_tree_with_utf8(tree)

=== modified file 'bzrlib/tests/tree_implementations/test_walkdirs.py'
--- bzrlib/tests/tree_implementations/test_walkdirs.py	2007-02-22 15:39:23 +0000
+++ bzrlib/tests/tree_implementations/test_walkdirs.py	2007-04-14 11:55:51 +0000
@@ -16,34 +16,53 @@
 
 """Tests for the generic Tree.walkdirs interface."""
 
+from bzrlib.osutils import has_symlinks
 from bzrlib.tests.tree_implementations import TestCaseWithTree
 
 
 class TestWalkdirs(TestCaseWithTree):
 
-    def get_all_subdirs_expected(self, tree):
-        return [
-            (('', tree.path2id('')),
-            [
-             ('0file', '0file', 'file', None, '2file', 'file'),
-             ('1top-dir', '1top-dir', 'directory', None, '1top-dir', 'directory'),
-             (u'2utf\u1234file', u'2utf\u1234file', 'file', None,
-                                     u'0utf\u1234file'.encode('utf8'), 'file'),
-             ('symlink', 'symlink', 'symlink', None, 'symlink', 'symlink')
-            ]),
-            (('1top-dir', '1top-dir'),
-            [('1top-dir/0file-in-1topdir', '0file-in-1topdir', 'file', None, '1file-in-1topdir', 'file'),
-             ('1top-dir/1dir-in-1topdir', '1dir-in-1topdir', 'directory', None, '0dir-in-1topdir', 'directory'),
-            ]),
-            (('1top-dir/1dir-in-1topdir', '0dir-in-1topdir'),
-            [
-            ]),
-            ]
+    def get_all_subdirs_expected(self, tree, symlinks):
+        if symlinks:
+            return [
+                (('', tree.path2id('')),
+                [
+                 ('0file', '0file', 'file', None, '2file', 'file'),
+                 ('1top-dir', '1top-dir', 'directory', None, '1top-dir', 'directory'),
+                 (u'2utf\u1234file', u'2utf\u1234file', 'file', None,
+                                         u'0utf\u1234file'.encode('utf8'), 'file'),
+                 ('symlink', 'symlink', 'symlink', None, 'symlink', 'symlink')
+                ]),
+                (('1top-dir', '1top-dir'),
+                [('1top-dir/0file-in-1topdir', '0file-in-1topdir', 'file', None, '1file-in-1topdir', 'file'),
+                 ('1top-dir/1dir-in-1topdir', '1dir-in-1topdir', 'directory', None, '0dir-in-1topdir', 'directory'),
+                ]),
+                (('1top-dir/1dir-in-1topdir', '0dir-in-1topdir'),
+                [
+                ]),
+                ]
+        else:
+            return [
+                (('', tree.path2id('')),
+                [
+                 ('0file', '0file', 'file', None, '2file', 'file'),
+                 ('1top-dir', '1top-dir', 'directory', None, '1top-dir', 'directory'),
+                 (u'2utf\u1234file', u'2utf\u1234file', 'file', None,
+                                         u'0utf\u1234file'.encode('utf8'), 'file'),
+                ]),
+                (('1top-dir', '1top-dir'),
+                [('1top-dir/0file-in-1topdir', '0file-in-1topdir', 'file', None, '1file-in-1topdir', 'file'),
+                 ('1top-dir/1dir-in-1topdir', '1dir-in-1topdir', 'directory', None, '0dir-in-1topdir', 'directory'),
+                ]),
+                (('1top-dir/1dir-in-1topdir', '0dir-in-1topdir'),
+                [
+                ]),
+                ]
 
     def test_walkdir_root(self):
-        tree = self.get_tree_with_subdirs_and_all_content_types()
+        tree = self.get_tree_with_subdirs_and_all_supported_content_types(has_symlinks())
         tree.lock_read()
-        expected_dirblocks = self.get_all_subdirs_expected(tree)
+        expected_dirblocks = self.get_all_subdirs_expected(tree, has_symlinks())
         # test that its iterable by iterating
         result = []
         for dirinfo, block in tree.walkdirs():
@@ -61,11 +80,11 @@
         self.assertEqual(len(expected_dirblocks), len(result))
             
     def test_walkdir_subtree(self):
-        tree = self.get_tree_with_subdirs_and_all_content_types()
+        tree = self.get_tree_with_subdirs_and_all_supported_content_types(has_symlinks())
         # test that its iterable by iterating
         result = []
         tree.lock_read()
-        expected_dirblocks = self.get_all_subdirs_expected(tree)[1:]
+        expected_dirblocks = self.get_all_subdirs_expected(tree, has_symlinks())[1:]
         for dirinfo, block in tree.walkdirs('1top-dir'):
             newblock = []
             for row in block:

